@@ -6,18 +6,20 @@ from __future__ import absolute_import
 from .accounts_api import AccountsApi
 from .authentication_api import AuthenticationApi
 from .billing_api import BillingApi
+from .bulk_envelopes_api import BulkEnvelopesApi
 from .cloud_storage_api import CloudStorageApi
 from .connect_api import ConnectApi
 from .custom_tabs_api import CustomTabsApi
 from .diagnostics_api import DiagnosticsApi
+from .email_archive_api import EmailArchiveApi
 from .envelopes_api import EnvelopesApi
 from .folders_api import FoldersApi
 from .groups_api import GroupsApi
 from .notary_api import NotaryApi
 from .organizations_api import OrganizationsApi
 from .power_forms_api import PowerFormsApi
-from .signature_api import SignatureApi
 from .signing_groups_api import SigningGroupsApi
 from .templates_api import TemplatesApi
+from .trust_service_providers_api import TrustServiceProvidersApi
 from .users_api import UsersApi
 from .workspaces_api import WorkspacesApi
