@@ -17,8 +17,10 @@ IntegratorKey = os.environ.get("INTEGRATOR_KEY_JWT")
 BaseUrl = "https://demo.docusign.net/restapi"
 OauthHostName = "account-d.docusign.com"
 SignTest1File = "{}/docs/SignTest1.pdf".format(os.path.dirname(os.path.abspath(__file__)))
+brandFile = "{}/docs/brand.xml".format(os.path.dirname(os.path.abspath(__file__)))
 TemplateId = os.environ.get("TEMPLATE_ID")
 UserId = os.environ.get("USER_ID")
+BrandId = os.environ.get("BRAND_ID")
 PrivateKeyBytes = base64.b64decode(os.environ.get("PRIVATE_KEY"))
 
 
@@ -67,6 +69,8 @@ class SdkUnitTests(unittest.TestCase):
 
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
         self.api_client.rest_client.pool_manager.clear()
 
     def tearDown(self):
@@ -92,6 +96,42 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
+
+    def testTemplateGet(self):
+        try:
+            from docusign_esign import TemplatesApi
+            template_api = TemplatesApi(self.api_client)
+
+            template_obj = template_api.get(self.user_info.accounts[0].account_id, template_id=TemplateId).to_dict()
+
+            assert template_obj is not None
+            assert template_obj['uri'] is not None
+
+        except ApiException as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
+
+    def testPutUpdateBrandResourceByContentType(self):
+        try:
+            from docusign_esign import AccountsApi
+            acc_api = AccountsApi(self.api_client)
+            acc_obj = acc_api.update_brand_resources_by_content_type(self.user_info.accounts[0].account_id, BrandId, "email", brandFile)
+
+            assert acc_obj is not None
+            assert acc_obj.resources_content_uri is not None
+
+        except ApiException as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testRequestASignature(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -157,6 +197,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testRequestSignatureFromTemplate(self):
         template_role_name = 'Needs to sign'
@@ -202,6 +245,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testEmbeddedSigning(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -290,10 +336,14 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testCreateTemplate(self):
         with open(SignTest1File, 'rb') as sign_file:
             file_contents = sign_file.read()
+
         # Set properties
         email_subject = 'Please Sign my Python SDK Envelope (Embedded Signer)'
         email_blurb = 'Hello, Please sign my Python SDK Envelope.'
@@ -335,16 +385,14 @@ class SdkUnitTests(unittest.TestCase):
 
         signers = [signer]
         recipients = docusign.Recipients(signers=signers)
-
         template_name = 'myTemplate'
-        env_template_definition = docusign.EnvelopeTemplateDefinition(name=template_name)
 
         # Create the Envelope template
         envelope_template = docusign.EnvelopeTemplate(email_subject=email_subject,
                                                       email_blurb=email_blurb,
                                                       documents=documents,
                                                       recipients=recipients,
-                                                      envelope_template_definition=env_template_definition)
+                                                      name=template_name)
 
         templates_api = TemplatesApi()
 
@@ -358,6 +406,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testDownLoadEnvelopeDocuments(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -429,6 +480,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testListDocuments(self):
         auth_api = AuthenticationApi()
@@ -452,6 +506,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testResendEnvelope(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -523,11 +580,14 @@ class SdkUnitTests(unittest.TestCase):
                                                                         resend_envelope='true')
             assert recipients_update_summary is not None
             assert len(recipients_update_summary.recipient_update_results) > 0
-            assert ("SUCCESS" == recipients_update_summary.recipient_update_results[0].error_details.error_code)
+            assert ( None == recipients_update_summary.recipient_update_results[0].error_details)
 
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testGetDiagnosticLogs(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -616,6 +676,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testGetFormData(self):
         try:
@@ -631,6 +694,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testListTabs(self):
         # For this the template Role should be manager
@@ -687,6 +753,9 @@ class SdkUnitTests(unittest.TestCase):
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
     def testMoveEnvelopes(self):
         with open(SignTest1File, 'rb') as sign_file:
@@ -741,7 +810,6 @@ class SdkUnitTests(unittest.TestCase):
                                                           documents=documents,
                                                           recipients=recipients,
                                                           status=status)
-
         envelopes_api = EnvelopesApi()
 
         try:
@@ -759,24 +827,31 @@ class SdkUnitTests(unittest.TestCase):
             folders_api.move_envelopes(self.user_info.accounts[0].account_id, to_folder_id,
                                        folders_request=folders_request)
 
-            # Wait for 5 second to make sure the newly created envelope was moved to the 'sentitems' folder
+            # Wait for 3 second to make sure the newly created envelope was moved to the 'sentitems' folder
             # Note: It's discouraged to use sleep statement or to poll DocuSign for envelope status or folder id
             # In production, use DocuSign Connect to get notified when the status of the envelope have changed.
-            sleep(5)
+            # 3 Seconds because sometimes when not in public or slow networks, the call takes more time and fails for 1 second.
+            sleep(3)
             # Test if we moved the envelope to the correct folder
-            list_from_drafts_folder = folders_api.list_items(self.user_info.accounts[0].account_id, to_folder_id)
+
+            search_options = "true"
+            list_from_drafts_folder = folders_api.list_items(self.user_info.accounts[0].account_id, to_folder_id, include_items=search_options)
 
             assert list_from_drafts_folder is not None
 
-            for item in list_from_drafts_folder.folder_items:
-                if item.envelope_id == envelope_summary.envelope_id:
-                    return
+            for folder in list_from_drafts_folder.folders:
+                for list_item in folder.folder_items:
+                    if list_item.envelope_id == envelope_summary.envelope_id:
+                        return
 
             assert False
 
         except ApiException as e:
             print("\nException when calling DocuSign API: %s" % e)
             assert e is None  # make the test case fail in case of an API exception
+        except Exception as e:
+            print("\nException when calling DocuSign API: %s" % e)
+            assert e is None  # make the test case fail in case of an API exception
 
 
 if __name__ == '__main__':
